@@ -1,7 +1,7 @@
 <?php
 namespace Doctrine\Tests\Common\Proxy;
 
-use Doctrine\Common\Persistence\Mapping\ClassMetadata;
+use Doctrine\Persistence\Mapping\ClassMetadata;
 use Doctrine\Common\Proxy\Exception\UnexpectedValueException;
 use Doctrine\Common\Proxy\Proxy;
 use Doctrine\Common\Proxy\ProxyGenerator;
@@ -369,7 +369,7 @@ class ProxyLogicTest extends \PHPUnit\Framework\TestCase
         $unserialized = unserialize($serialized);
         $reflClass    = $this->lazyLoadableObjectMetadata->getReflectionClass();
 
-        self::assertFalse($unserialized->__isInitialized(), 'serialization didn\'t cause intialization');
+        self::assertFalse($unserialized->__isInitialized(), 'serialization didn\'t cause initialization');
 
         // Checking identifiers
         self::assertSame('publicIdentifierFieldValue', $unserialized->publicIdentifierField, 'identifiers are kept');
@@ -432,7 +432,7 @@ class ProxyLogicTest extends \PHPUnit\Framework\TestCase
         /** @var LazyLoadableObject&Proxy $unserialized */
         $unserialized = unserialize($serialized);
 
-        self::assertTrue($unserialized->__isInitialized(), 'serialization didn\'t cause intialization');
+        self::assertTrue($unserialized->__isInitialized(), 'serialization didn\'t cause initialization');
 
         // Checking transient fields
         self::assertSame(
